# XDOTOOL

<div align="center">

[![Downloads](https://static.pepy.tech/personalized-badge/xdotool?period=month&units=international_system&left_color=grey&right_color=blue&left_text=PyPi%20Downloads)](https://pepy.tech/project/xdotool)
[![Stars](https://img.shields.io/github/stars/Tlaloc-Es/xdotool?color=yellow&style=flat)](https://github.com/Tlaloc-Es/xdotool/stargazers)

</div>

Library to use pose estimation in your projects easily.
## Instalation [![PyPI](https://img.shields.io/pypi/v/xdotool.svg)](https://pypi.org/project/xdotool/)

You can install `xdotool` from [Pypi](https://pypi.org/project/xdotool/). It's going to install the library itself and its prerequisites as well.

```bash
pip install xdotool
```

You can install `xdotool` from its source code.

```bash
git clone https://github.com/Tlaloc-Es/xdotool.git
cd xdotool
pip install -e .
```
